<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu_HU">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Wally</source>
        <translation>A Wally névjegye</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;/head&gt;&lt;body&gt;&lt;font size=&quot;+1&quot;&gt;Qt4 desktop wallpaper changer&lt;br /&gt;Author: Antonio Di Monaco (a.k.a. &lt;i&gt;Sin(x) &apos;76&lt;/i&gt;)&lt;br /&gt;I&apos;d like to thank Vincent Willem van Gogh for the logo :)&lt;br /&gt;&lt;br /&gt;Web site: &lt;a href=&quot;http://www.becrux.com&quot;&gt;http://www.becrux.com&lt;/a&gt;&lt;br /&gt;You can contact me at &lt;a href=&quot;mailto:tony@becrux.com?subject=About Wally&quot;&gt;tony@becrux.com&lt;/font&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;/head&gt;&lt;body&gt;&lt;font size=&quot;+1&quot;&gt;Qt4 háttérkép cserélő&lt;br /&gt;Készítette: Antonio Di Monaco (a.k.a. &lt;i&gt;Sin(x) &apos;76&lt;/i&gt;)&lt;br /&gt;Szeretnék köszönetet mondani Vincent Willem van Goghnak az induló képért :)&lt;br /&gt;&lt;br /&gt;Honlap: &lt;a href=&quot;http://www.becrux.com&quot;&gt;http://www.becrux.com&lt;/a&gt;&lt;br /&gt;Kapcsolat &lt;a href=&quot;mailto:tony@becrux.com?subject=About Wally&quot;&gt;tony@becrux.com&lt;/font&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Details &gt;&gt;</source>
        <translation>Részletek &gt;&gt;</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezár</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Kiterjesztés</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
    <message>
        <source>Supported image formats:</source>
        <translation>Támogatott képformátumok:</translation>
    </message>
    <message>
        <source>Additional info:</source>
        <translation>További információ:</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Nyelv</translation>
    </message>
    <message>
        <source>Translator</source>
        <translation>Fordító</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>Fordítások:</translation>
    </message>
    <message>
        <source>Compiled with:</source>
        <translation>Szerkesztő program:</translation>
    </message>
    <message>
        <source>EXIF library:</source>
        <translation>EXIF könyvtár:</translation>
    </message>
    <message>
        <source>present</source>
        <translation>létező</translation>
    </message>
    <message>
        <source>not present</source>
        <translation>nem létező</translation>
    </message>
    <message>
        <source>English</source>
        <translation>angol</translation>
    </message>
    <message>
        <source>Italian</source>
        <translation>olasz</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>orosz</translation>
    </message>
    <message>
        <source>Spanish</source>
        <translation>spanyol</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation>portugál (brazil)</translation>
    </message>
    <message>
        <source>German</source>
        <translation>német</translation>
    </message>
    <message>
        <source>French</source>
        <translation>francia</translation>
    </message>
    <message>
        <source>Czech</source>
        <translation>cseh</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>kínai</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation>lengyel</translation>
    </message>
    <message>
        <source>Catalan</source>
        <translation>katalán</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation>görög</translation>
    </message>
    <message>
        <source>Korean</source>
        <translation>koreai</translation>
    </message>
    <message>
        <source>Hungarian</source>
        <translation>Magyar</translation>
    </message>
    <message>
        <source>Danish</source>
        <translation>Dán</translation>
    </message>
    <message>
        <source>Swedish</source>
        <translation>Svéd</translation>
    </message>
    <message>
        <source>Turkish</source>
        <translation>Török</translation>
    </message>
</context>
<context>
    <name>Bing::DialogWidget</name>
    <message>
        <source>All of these words</source>
        <translation>Minden szó</translation>
    </message>
    <message>
        <source>Any of these words</source>
        <translation>Bármely szó</translation>
    </message>
    <message>
        <source>Search for:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <source>Strict</source>
        <translation>Pontos</translation>
    </message>
    <message>
        <source>Moderate</source>
        <translation>Moderált</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Kikapcsolva</translation>
    </message>
    <message>
        <source>Adult filter:</source>
        <translation>Korhatár szűrő:</translation>
    </message>
    <message>
        <source>Bing item</source>
        <translation>Bing cikkely</translation>
    </message>
    <message>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>A nem szűrt tartalomban megjelennek a sértő és szexuális fotók</translation>
    </message>
    <message>
        <source>Edit Bing item</source>
        <translation>Bing szerkesztése</translation>
    </message>
    <message>
        <source>Add Bing item</source>
        <translation>Bing hozzáadása</translation>
    </message>
</context>
<context>
    <name>Bing::Item</name>
    <message>
        <source>Tags:</source>
        <translation>Címkék:</translation>
    </message>
    <message>
        <source>and</source>
        <translation>és</translation>
    </message>
    <message>
        <source>or</source>
        <translation>vagy</translation>
    </message>
    <message>
        <source>Adult filter:</source>
        <translation>Korhatár szűrő:</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Ki</translation>
    </message>
    <message>
        <source>Moderate</source>
        <translation>Moderált</translation>
    </message>
    <message>
        <source>Strict</source>
        <translation>Pontos</translation>
    </message>
</context>
<context>
    <name>Buzznet::DialogWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <source>Edit Buzznet item</source>
        <translation>Buzznet szerkesztése</translation>
    </message>
    <message>
        <source>Add Buzznet item</source>
        <translation>Buzznet hozzáadása</translation>
    </message>
</context>
<context>
    <name>Buzznet::Item</name>
    <message>
        <source>Tag:</source>
        <translation>Címke:</translation>
    </message>
</context>
<context>
    <name>DeviantArt::DialogWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <source>Strict</source>
        <translation>Pontos</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Ki</translation>
    </message>
    <message>
        <source>Adult filter:</source>
        <translation>Korhatár szűrő:</translation>
    </message>
    <message>
        <source>deviantART item</source>
        <translation>devianART cikkely</translation>
    </message>
    <message>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>A nem szűrt tartalomban megjelennek a sértő és szexuális fotók</translation>
    </message>
    <message>
        <source>Edit deviantART item</source>
        <translation>devianART szerkesztése</translation>
    </message>
    <message>
        <source>Add deviantART item</source>
        <translation>devianART hozzáadása</translation>
    </message>
</context>
<context>
    <name>DeviantArt::Item</name>
    <message>
        <source>Tag:</source>
        <translation>Címke:</translation>
    </message>
    <message>
        <source>Adult filter:</source>
        <translation>Korhatár szűrő:</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Ki</translation>
    </message>
    <message>
        <source>Strict</source>
        <translation>Pontos</translation>
    </message>
</context>
<context>
    <name>Exif::InfoDialog</name>
    <message>
        <source>EXIF information</source>
        <translation>EXIF adatok</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Címke</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Érték</translation>
    </message>
    <message>
        <source>No EXIF information available</source>
        <translation>EXIF adatok nem elérhetők</translation>
    </message>
</context>
<context>
    <name>Files::Core</name>
    <message>
        <source>Loading folder...</source>
        <translation>Mappa beolvasása...</translation>
    </message>
</context>
<context>
    <name>Files::LabelPreview</name>
    <message>
        <source>No preview available</source>
        <translation>Előnézet nem elérhető</translation>
    </message>
</context>
<context>
    <name>Files::SettingsWidget</name>
    <message>
        <source>Files</source>
        <translation>Fájlok</translation>
    </message>
    <message>
        <source>Select a photo</source>
        <translation>Kép választása</translation>
    </message>
    <message>
        <source>Select a folder</source>
        <translation>Mappa választása</translation>
    </message>
</context>
<context>
    <name>FilesSettingsWidget</name>
    <message>
        <source>Photos</source>
        <translation>Képek</translation>
    </message>
    <message>
        <source>Add a photo</source>
        <translation>Kép hozzáadása</translation>
    </message>
    <message>
        <source>Add photos in folder</source>
        <translation>Mappa képeinek hozzáadása</translation>
    </message>
    <message>
        <source>Delete photo</source>
        <translation>Kép törlése</translation>
    </message>
    <message>
        <source>Move photo up</source>
        <translation>Kép felfelé</translation>
    </message>
    <message>
        <source>Move photo down</source>
        <translation>Kép lefelé</translation>
    </message>
</context>
<context>
    <name>Flickr::DialogWidget</name>
    <message>
        <source>All of these words</source>
        <translation>Minden szó</translation>
    </message>
    <message>
        <source>Any of these words</source>
        <translation>Bármely szó</translation>
    </message>
    <message>
        <source>Search for:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <source>Full text</source>
        <translation>Teljes szöveg</translation>
    </message>
    <message>
        <source>Tags only</source>
        <translation>Csak címkék</translation>
    </message>
    <message>
        <source>Largest</source>
        <translation>Legnagyobb</translation>
    </message>
    <message>
        <source>Original</source>
        <translation>Eredeti</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Nagy</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Közepes</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Kicsi</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Bélyegkép</translation>
    </message>
    <message>
        <source>Square</source>
        <translation>Négyzet alakú</translation>
    </message>
    <message>
        <source>Smallest</source>
        <translation>Legkisebb</translation>
    </message>
    <message>
        <source>Interestingness desc</source>
        <translation>Legkeresettebb szerint csökkenő</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Fontosság</translation>
    </message>
    <message>
        <source>Date posted desc</source>
        <translation>Közlés dátuma szerint csökkenő</translation>
    </message>
    <message>
        <source>Date taken desc</source>
        <translation>Feltöltés szerinti csökkenő</translation>
    </message>
    <message>
        <source>Interestingness asc</source>
        <translation>Legkeresettebb szerint növekvő</translation>
    </message>
    <message>
        <source>Date posted asc</source>
        <translation>Közlés dátuma szerint növekvő</translation>
    </message>
    <message>
        <source>Date taken asc</source>
        <translation>Feltöltés szerinti növekvő</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Méret:</translation>
    </message>
    <message>
        <source>Order:</source>
        <translation>Sorrend:</translation>
    </message>
    <message>
        <source>Edit Flickr item</source>
        <translation>Flickr szerkesztése</translation>
    </message>
    <message>
        <source>Add Flickr item</source>
        <translation>Flickr hozzáadása</translation>
    </message>
</context>
<context>
    <name>Flickr::Item</name>
    <message>
        <source>Text:</source>
        <translation>Szöveg:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Címkék:</translation>
    </message>
    <message>
        <source>and</source>
        <translation>és</translation>
    </message>
    <message>
        <source>or</source>
        <translation>vagy</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Méret:</translation>
    </message>
    <message>
        <source>Largest</source>
        <translation>Legnagyobb</translation>
    </message>
    <message>
        <source>Original</source>
        <translation>Eredeti</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Nagy</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Közepes</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Kicsi</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Bélyegkép</translation>
    </message>
    <message>
        <source>Square</source>
        <translation>Négyzet</translation>
    </message>
    <message>
        <source>Smallest</source>
        <translation>Legkisebb</translation>
    </message>
    <message>
        <source>Order:</source>
        <translation>Sorrend:</translation>
    </message>
    <message>
        <source>Interestingness desc</source>
        <translation>Legkeresettebb szerint csökkenő</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Fontosság</translation>
    </message>
    <message>
        <source>Date posted desc</source>
        <translation>Közlés dátuma szerint csökkenő</translation>
    </message>
    <message>
        <source>Date taken desc</source>
        <translation>Feltöltés szerinti csökkenő</translation>
    </message>
    <message>
        <source>Interestingness asc</source>
        <translation>Legkeresettebb szerint növekvő</translation>
    </message>
    <message>
        <source>Date posted asc</source>
        <translation>Közlés dátuma szerint növekvő</translation>
    </message>
    <message>
        <source>Date taken asc</source>
        <translation>Feltöltés szerinti növekvő</translation>
    </message>
</context>
<context>
    <name>Folders::DialogWidget</name>
    <message>
        <source>Local</source>
        <translation>Helyi</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>Távoli</translation>
    </message>
    <message>
        <source>Include subfolders</source>
        <translation>Alkönyvtárakkal együtt</translation>
    </message>
    <message>
        <source>Folder:</source>
        <translation>Mappa:</translation>
    </message>
    <message>
        <source>Passive</source>
        <translation>Passzív</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktív</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Szerver:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Transfer mode:</source>
        <translation>Átvitel módja:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Felhasználónév:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Jelszó:</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation>Útvonal:</translation>
    </message>
    <message>
        <source>Select a folder</source>
        <translation>Mappa választása</translation>
    </message>
    <message>
        <source>Edit folder</source>
        <translation>Mappa szerkesztése</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Mappa hozzáadása</translation>
    </message>
</context>
<context>
    <name>Folders::LocalItem</name>
    <message>
        <source>(with subfolders)</source>
        <translation>(alkönyvtárakkal együtt)</translation>
    </message>
</context>
<context>
    <name>Folders::RemoteItem</name>
    <message>
        <source>Transfer mode:</source>
        <translation>Átvitel módja:</translation>
    </message>
    <message>
        <source>passive</source>
        <translation>Passzív</translation>
    </message>
    <message>
        <source>active</source>
        <translation>Aktív</translation>
    </message>
</context>
<context>
    <name>Folders::SettingsWidget</name>
    <message>
        <source>Folders</source>
        <translation>Mappák</translation>
    </message>
</context>
<context>
    <name>FoldersSettingsWidget</name>
    <message>
        <source>Folders</source>
        <translation>Mappák</translation>
    </message>
    <message>
        <source>Add a folder</source>
        <translation>Mappa hozzáadása</translation>
    </message>
    <message>
        <source>Delete folder</source>
        <translation>Mappa törlése</translation>
    </message>
</context>
<context>
    <name>Google::DialogWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <source>Strict</source>
        <translation>Pontos</translation>
    </message>
    <message>
        <source>Moderate</source>
        <translation>Moderált</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Ki</translation>
    </message>
    <message>
        <source>Adult filter:</source>
        <translation>Korhatár szűrő:</translation>
    </message>
    <message>
        <source>Google item</source>
        <translation>Google cikkely</translation>
    </message>
    <message>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>A nem szűrt tartalomban megjelennek a sértő és szexuális fotók</translation>
    </message>
    <message>
        <source>Edit Google item</source>
        <translation>Google szerkesztése</translation>
    </message>
    <message>
        <source>Add Google item</source>
        <translation>Google hozzáadása</translation>
    </message>
</context>
<context>
    <name>Google::Item</name>
    <message>
        <source>Text:</source>
        <translation>Szöveg:</translation>
    </message>
    <message>
        <source>Adult filter:</source>
        <translation>Korhatár szűrő:</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Ki</translation>
    </message>
    <message>
        <source>Moderate</source>
        <translation>Moderált</translation>
    </message>
    <message>
        <source>Strict</source>
        <translation>Pontos</translation>
    </message>
</context>
<context>
    <name>Gui::ColorButton</name>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
</context>
<context>
    <name>History::Dialog</name>
    <message>
        <source>Right-click on items to show options</source>
        <translation>Jobb klikk a cikkelyen megmutatja az opciókat</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Történet</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation>Kérem, várjon...</translation>
    </message>
    <message>
        <source>Downloading photo...</source>
        <translation>A fotó letöltődik...</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Megszakítás</translation>
    </message>
    <message>
        <source>Save photo</source>
        <translation>Fotó mentése</translation>
    </message>
    <message>
        <source>Images (*.png *.xpm *.jpg)</source>
        <translation>Képek (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <source>Photo has been saved</source>
        <translation>Fotó elmentve</translation>
    </message>
    <message>
        <source>There was an error during download</source>
        <translation>Hiba a letöltés közben</translation>
    </message>
    <message>
        <source>View photo...</source>
        <translation>Fotó megtekintése...</translation>
    </message>
    <message>
        <source>Get EXIF info...</source>
        <translation>EXIF adatok megtekintése...</translation>
    </message>
    <message>
        <source>Save photo...</source>
        <translation>Fotó mentése...</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation>Beállítás háttérképként</translation>
    </message>
    <message>
        <source>Explore image source</source>
        <translation>Képforrás kutatása</translation>
    </message>
</context>
<context>
    <name>History::EngineQueryModel</name>
    <message>
        <source>All</source>
        <translation>Mind</translation>
    </message>
</context>
<context>
    <name>History::PhotosQueryModel</name>
    <message>
        <source>(no title)</source>
        <translation>(nincs felirat)</translation>
    </message>
    <message>
        <source>by:</source>
        <translation>készítő:</translation>
    </message>
    <message>
        <source>(no author)</source>
        <translation>(nincs alkotó)</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Dátum:</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Hely:</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>ismeretlen</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Méret:</translation>
    </message>
    <message>
        <source>Image size:</source>
        <translation>Kép mérete:</translation>
    </message>
    <message>
        <source>Engine:</source>
        <translation>Forrás:</translation>
    </message>
    <message>
        <source>EXIF:</source>
        <translation>EXIF:</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nem</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Igen</translation>
    </message>
</context>
<context>
    <name>History::TagsQueryModel</name>
    <message>
        <source>All</source>
        <translation>Mind</translation>
    </message>
</context>
<context>
    <name>HttpEngine::SettingsWidget</name>
    <message>
        <source>Select a folder</source>
        <translation>Mappa választása</translation>
    </message>
</context>
<context>
    <name>HttpSettingsWidget</name>
    <message>
        <source>Photo sets</source>
        <translation>Képgyűjtemények</translation>
    </message>
    <message>
        <source>Add a photo set</source>
        <translation>Képgyűjtemény hozzáadása</translation>
    </message>
    <message>
        <source>Delete photo set</source>
        <translation>Képgyűjtemény törlése</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciók</translation>
    </message>
    <message>
        <source>Save photos</source>
        <translation>Fotók mentése</translation>
    </message>
</context>
<context>
    <name>Ipernity::DialogWidget</name>
    <message>
        <source>All of these words</source>
        <translation>Minden szó</translation>
    </message>
    <message>
        <source>Any of these words</source>
        <translation>Bármely szó</translation>
    </message>
    <message>
        <source>Search for:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <source>Full text</source>
        <translation>Teljes szöveg</translation>
    </message>
    <message>
        <source>Tags only</source>
        <translation>Csak címkék</translation>
    </message>
    <message>
        <source>Ipernity item</source>
        <translation>Ipernity cikkely</translation>
    </message>
    <message>
        <source>It can show offending or sexual explicit photos</source>
        <translation>Megjelenhetnek a sértő és szexuális fotók</translation>
    </message>
    <message>
        <source>Edit Ipernity item</source>
        <translation>Ipernity szerkesztése</translation>
    </message>
    <message>
        <source>Add Ipernity item</source>
        <translation>Ipernity hozzáadás</translation>
    </message>
</context>
<context>
    <name>Ipernity::Item</name>
    <message>
        <source>Text:</source>
        <translation>Szöveg:</translation>
    </message>
    <message>
        <source>and</source>
        <translation>és</translation>
    </message>
    <message>
        <source>or</source>
        <translation>vagy</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Címkék:</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Another instance of</source>
        <translation>Másik kérelem</translation>
    </message>
    <message>
        <source>is already running</source>
        <translation>már folyamatban</translation>
    </message>
    <message>
        <source>Disclaimer</source>
        <translation>Visszautasítás</translation>
    </message>
    <message>
        <source>&lt;b&gt;The Author takes no responsibility over the content that Wally downloads from photo sharing web sites.&lt;br&gt;The Author is in no way responsible for any such content.&lt;/b&gt;&lt;br&gt;&lt;br&gt;If this is a problem for you, please use only local engines like &quot;Files&quot; or local &quot;Folders&quot;.&lt;br&gt;Otherwise, please select &lt;b&gt;&quot;No&quot;&lt;/b&gt; to exit Wally, or use it &lt;b&gt;at your own risk.&lt;/b&gt;&lt;br&gt;&lt;br&gt;(If you proceed, this message will appear only once)&lt;br&gt;&lt;br&gt;Do you accept the above condition?</source>
        <translation>&lt;b&gt;Az alkotó nem járult hozzá a tartalom Wallyval történő letöltéséhez&lt;br&gt;Az alkotó nem vállal felelősséget a tartalomért&lt;/b&gt;&lt;br&gt;&lt;br&gt;Ha ez problémát okoz, használja a &quot;Fájlok&quot; vagy &quot;Könyvtárak&quot; helyi lehetőséget!&lt;br&gt;Vagy válassza a &lt;b&gt;Nem-et&lt;/b&gt;a Wallyból való kilépésre, vagy használja &lt;b&gt;saját felelősségre!&lt;/b&gt;&lt;br&gt;&lt;br&gt;(Ha elfogadja, akkor ez az üzenet nem jelenik meg többször)&lt;br&gt;&lt;br&gt;Elfogadja a fenti feltételeket?</translation>
    </message>
</context>
<context>
    <name>Map::View</name>
    <message>
        <source>Drag to select. Right-click to zoom</source>
        <translation>Ragadja meg a kiválasztáshoz! Jobb klikk a nagyításhoz</translation>
    </message>
    <message>
        <source>Zoom %1x</source>
        <translation>Nagyítás %1x</translation>
    </message>
</context>
<context>
    <name>Map::Viewer</name>
    <message>
        <source>Map viewer</source>
        <translation>Térkép néző</translation>
    </message>
</context>
<context>
    <name>Panoramio::DialogWidget</name>
    <message>
        <source>Select on map</source>
        <translation>Választás a térképen</translation>
    </message>
    <message>
        <source>Longitude (min):</source>
        <translation>Hosszúsági fok (minimum):</translation>
    </message>
    <message>
        <source>Longitude (max):</source>
        <translation>Hosszúsági fok (maximum):</translation>
    </message>
    <message>
        <source>Latitude (min):</source>
        <translation>Szélességi fok (minimum):</translation>
    </message>
    <message>
        <source>Latitude (max):</source>
        <translation>Szélességi fok (maximum):</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Népszerűség</translation>
    </message>
    <message>
        <source>Upload date</source>
        <translation>Feltöltés dátuma</translation>
    </message>
    <message>
        <source>Original</source>
        <translation>Eredeti</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Közepes</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Kicsi</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Bélyegkép</translation>
    </message>
    <message>
        <source>Square</source>
        <translation>Négyzet alakú</translation>
    </message>
    <message>
        <source>Mini square</source>
        <translation>Kis négyzet alakú</translation>
    </message>
    <message>
        <source>Order:</source>
        <translation>Sorrend:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Méret:</translation>
    </message>
    <message>
        <source>Edit Panoramio item</source>
        <translation>Panoramio szerkesztése</translation>
    </message>
    <message>
        <source>Add Panoramio item</source>
        <translation>Panoramio hozzáadása</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Coordinates must be different</source>
        <translation>A koordinátáknak különbözőeknek kell lenniük</translation>
    </message>
</context>
<context>
    <name>Panoramio::Item</name>
    <message>
        <source>lat:</source>
        <translation>szélességi:</translation>
    </message>
    <message>
        <source>lon:</source>
        <translation>hosszúsági:</translation>
    </message>
    <message>
        <source>Original</source>
        <translation>Eredeti</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Közepes</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Kicsi</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Bélyegkép</translation>
    </message>
    <message>
        <source>Square</source>
        <translation>Négyzet alakú</translation>
    </message>
    <message>
        <source>Mini square</source>
        <translation>Kis négyzet alakú</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Népszerűség</translation>
    </message>
    <message>
        <source>Upload date</source>
        <translation>Feltöltés dátuma</translation>
    </message>
    <message>
        <source>Longitude:</source>
        <translation>Hosszúsági fok:</translation>
    </message>
    <message>
        <source>Latitude:</source>
        <translation>Szélességi fok:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Méret:</translation>
    </message>
    <message>
        <source>Order:</source>
        <translation>Sorrend:</translation>
    </message>
</context>
<context>
    <name>Photobucket::DialogWidget</name>
    <message>
        <source>All of these words</source>
        <translation>Minden szó</translation>
    </message>
    <message>
        <source>Any of these words</source>
        <translation>Bármely szó</translation>
    </message>
    <message>
        <source>Search for:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <source>Photobucket item</source>
        <translation>Photobucket cikkely</translation>
    </message>
    <message>
        <source>It can show offending or sexual explicit photos</source>
        <translation>Megjelenhetnek a sértő és szexuális fotók</translation>
    </message>
    <message>
        <source>Edit Photobucket item</source>
        <translation>Photobucket szerkesztése</translation>
    </message>
    <message>
        <source>Add Photobucket item</source>
        <translation>Photobucket hozzáadása</translation>
    </message>
</context>
<context>
    <name>Photobucket::Item</name>
    <message>
        <source>Text:</source>
        <translation>Szöveg:</translation>
    </message>
    <message>
        <source>and</source>
        <translation>és</translation>
    </message>
    <message>
        <source>or</source>
        <translation>vagy</translation>
    </message>
</context>
<context>
    <name>Picasa::DialogWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <source>Edit Picasa item</source>
        <translation>Picasa szerkesztése</translation>
    </message>
    <message>
        <source>Add Picasa item</source>
        <translation>Picasa hozzáadása</translation>
    </message>
</context>
<context>
    <name>Picasa::Item</name>
    <message>
        <source>Text:</source>
        <translation>Szöveg:</translation>
    </message>
</context>
<context>
    <name>Pikeo::DialogWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Alapértelmezés</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Legnézettebb</translation>
    </message>
    <message>
        <source>Upload date</source>
        <translation>Feltöltés dátuma</translation>
    </message>
    <message>
        <source>Date taken</source>
        <translation>Feltöltés szerinti</translation>
    </message>
    <message>
        <source>Group add date</source>
        <translation>Dátum szerinti csoportosítás</translation>
    </message>
    <message>
        <source>Comment date</source>
        <translation>Hozzászólás dátuma</translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation>Növekvő</translation>
    </message>
    <message>
        <source>Order:</source>
        <translation>Sorrend:</translation>
    </message>
    <message>
        <source>Edit Pikeo item</source>
        <translation>Pikeo szerkesztése</translation>
    </message>
    <message>
        <source>Add Pikeo item</source>
        <translation>Pikeo hozzáadása</translation>
    </message>
</context>
<context>
    <name>Pikeo::Item</name>
    <message>
        <source>Tags:</source>
        <translation>Címkék:</translation>
    </message>
    <message>
        <source>Order:</source>
        <translation>Sorrend:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Alapértelmezés</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Legnézettebb</translation>
    </message>
    <message>
        <source>Upload date</source>
        <translation>Feltöltés dátuma</translation>
    </message>
    <message>
        <source>Date taken</source>
        <translation>Feltöltés szerinti</translation>
    </message>
    <message>
        <source>Group add date</source>
        <translation>Dátum szerinti csoportosítás</translation>
    </message>
    <message>
        <source>Comment date</source>
        <translation>Hozzászólás dátuma</translation>
    </message>
    <message>
        <source>ascending</source>
        <translation>Növekvő</translation>
    </message>
    <message>
        <source>descending</source>
        <translation>csökkenő</translation>
    </message>
</context>
<context>
    <name>PositionModel</name>
    <message>
        <source>Position</source>
        <translation>Pozíció</translation>
    </message>
    <message>
        <source>Picture smaller than screen on the left, greater than screen on the right</source>
        <translation>Kép kisebb mint a képernyő bal oldala, nagyobb mint a képernyő jobb oldala</translation>
    </message>
</context>
<context>
    <name>QColorDialog</name>
    <message>
        <source>Hu&amp;e:</source>
        <translation>Színárn&amp;yalat:</translation>
    </message>
    <message>
        <source>&amp;Sat:</source>
        <translation>&amp;Telítettség:</translation>
    </message>
    <message>
        <source>&amp;Val:</source>
        <translation>É&amp;rték:</translation>
    </message>
    <message>
        <source>&amp;Red:</source>
        <translation>&amp;Piros:</translation>
    </message>
    <message>
        <source>&amp;Green:</source>
        <translation>&amp;Zöld:</translation>
    </message>
    <message>
        <source>Bl&amp;ue:</source>
        <translation>Ké&amp;k:</translation>
    </message>
    <message>
        <source>Select Color</source>
        <translation>Válasszon színt</translation>
    </message>
    <message>
        <source>&amp;Basic colors</source>
        <translation>&amp;Alapszínek</translation>
    </message>
    <message>
        <source>&amp;Custom colors</source>
        <translation>&amp;Egyéni színek</translation>
    </message>
    <message>
        <source>&amp;Add to Custom Colors</source>
        <translation>&amp;Hozzáadás az egyéni színekhez</translation>
    </message>
</context>
<context>
    <name>QDialogButtonBox</name>
    <message>
        <source>OK</source>
        <translation>Rendben</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Visszaállítás</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Igen</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nem</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezár</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Bezár</translation>
    </message>
</context>
<context>
    <name>QFileDialog</name>
    <message>
        <source>Directories</source>
        <translation>Könyvtárak</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Megnyitás</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Menté&amp;s</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 már létezik.
Lecseréli?</translation>
    </message>
    <message>
        <source>%1
File not found.
Please verify the correct file name was given.</source>
        <translation>%1 fájl nem található.
Kérem, ellenőrizze a helyes fájlnevet.</translation>
    </message>
    <message>
        <source>My Computer</source>
        <translation>Számítógépem</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>Át&amp;nevezés</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Törlés</translation>
    </message>
    <message>
        <source>Show &amp;hidden files</source>
        <translation>Rejtett &amp;fájlok megjelenítése</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <source>Parent Directory</source>
        <translation>Szülő könyvtár</translation>
    </message>
    <message>
        <source>List View</source>
        <translation>Listanézet</translation>
    </message>
    <message>
        <source>Detail View</source>
        <translation>Részletes nézet</translation>
    </message>
    <message>
        <source>Files of type:</source>
        <translation>Fájltípusok:</translation>
    </message>
    <message>
        <source>Directory:</source>
        <translation>Könyvtár:</translation>
    </message>
    <message>
        <source>%1
Directory not found.
Please verify the correct directory name was given.</source>
        <translation>%1
Könyvtár nem található.
Kérem, ellenőrizze a helyes fájlnevet.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is write protected.
Do you want to delete it anyway?</source>
        <translation>&apos;%1&apos; írásvédett. Mindeképpen törli?</translation>
    </message>
    <message>
        <source>Are sure you want to delete &apos;%1&apos;?</source>
        <translation>Biztosan törölni akarja &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Could not delete directory.</source>
        <translation>A könyvtár nem törölhető.</translation>
    </message>
    <message>
        <source>Recent Places</source>
        <translation>Újabb helyek</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Mentés mint</translation>
    </message>
    <message>
        <source>Drive</source>
        <translation>Meghajtó</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fájl</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
    <message>
        <source>Find Directory</source>
        <translation>Könyvtár keresése</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Mutasd</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Előre</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Új mappa</translation>
    </message>
    <message>
        <source>&amp;New Folder</source>
        <translation>Ú&amp;j mappa</translation>
    </message>
    <message>
        <source>&amp;Choose</source>
        <translation>&amp;Válassz</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>File &amp;name:</source>
        <translation>Fájl &amp;neve:</translation>
    </message>
    <message>
        <source>Look in:</source>
        <translation>Betekintés:</translation>
    </message>
    <message>
        <source>Create New Folder</source>
        <translation>Új mappa létrehozása</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Centered</source>
        <translation>Középre</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Mozaikszerűen</translation>
    </message>
    <message>
        <source>Center Tiled</source>
        <translation>Középre mozaikszerűen</translation>
    </message>
    <message>
        <source>Centered Maxpect</source>
        <translation>Középre nyújtva</translation>
    </message>
    <message>
        <source>Tiled Maxpect</source>
        <translation>Mozaikszerűen nyújtva</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Nagyítva</translation>
    </message>
    <message>
        <source>Centered Auto Fit</source>
        <translation>Középre automatikusan</translation>
    </message>
    <message>
        <source>Scale &amp; Crop</source>
        <translation>Nagyítva &amp; levágva</translation>
    </message>
    <message>
        <source>Symmetrical Tiled</source>
        <translation>Szimmetrikus mozaik</translation>
    </message>
    <message>
        <source>Mirrored Tiled</source>
        <translation>Tükrözve mozaikszerűen</translation>
    </message>
    <message>
        <source>Symmetrical Mirrored Tiled</source>
        <translation>Szimmetrikusan tükrözött mozaik</translation>
    </message>
    <message>
        <source>All image files</source>
        <translation>Minden képfájl</translation>
    </message>
    <message>
        <source>files</source>
        <translation>fájlok</translation>
    </message>
</context>
<context>
    <name>QProgressDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>General options</source>
        <translation>Általános opciók</translation>
    </message>
    <message>
        <source>Interval:</source>
        <translation>Távköz:</translation>
    </message>
    <message>
        <source>Border:</source>
        <translation>Keret:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Pozíció:</translation>
    </message>
    <message>
        <source>Main</source>
        <translation>Fő</translation>
    </message>
    <message>
        <source>Choose in random order</source>
        <translation>Véletlenszerű sorrend</translation>
    </message>
    <message>
        <source>Switch background on play</source>
        <translation>Háttérváltás futás közben</translation>
    </message>
    <message>
        <source>Play automatically on application start</source>
        <translation>Automatikus cserélés induláskor</translation>
    </message>
    <message>
        <source>Disable splash screen</source>
        <translation>Felugró képernyő tiltása</translation>
    </message>
    <message>
        <source>Quit after background change</source>
        <translation>Hátérképcsere után kilép</translation>
    </message>
    <message>
        <source>Start automatically when system starts</source>
        <translation>Automatikus cserélés rendszerinduláskor</translation>
    </message>
    <message>
        <source>Only use landscape-oriented photos</source>
        <translation>Csak fekvő fotók használata</translation>
    </message>
    <message>
        <source>Rotate images according to EXIF information</source>
        <translation>EXIF információk szerinti képelfordítás</translation>
    </message>
    <message>
        <source>View info on photo</source>
        <translation>Információ mutatása a fotón</translation>
    </message>
    <message>
        <source>View info in system tray tooltip</source>
        <translation>Információ mutatása a rendszertálca ikonon</translation>
    </message>
    <message>
        <source>Use full desktop area</source>
        <translation>Teljes képernyő használata</translation>
    </message>
    <message>
        <source>Photo has to be</source>
        <translation>A fotó legyen</translation>
    </message>
    <message>
        <source>independent of</source>
        <translation>független az</translation>
    </message>
    <message>
        <source>at least 1/2 of</source>
        <translation>fele az</translation>
    </message>
    <message>
        <source>at least 3/4 of</source>
        <translation>háronegyede az</translation>
    </message>
    <message>
        <source>bigger than</source>
        <translation>nagyobb mint az</translation>
    </message>
    <message>
        <source>desktop&apos;s size</source>
        <translation>asztal mérete</translation>
    </message>
    <message>
        <source>Don&apos;t save locally remote photos if free disk space goes below</source>
        <translation>Ne mentse el a fotókat, ha a lemez mérete kisebb mint</translation>
    </message>
    <message>
        <source>Store images in history for</source>
        <translation>Őrizze meg a képeket az archívumban</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Available modules:</source>
        <translation>Elérhető modulok:</translation>
    </message>
    <message>
        <source>Active modules:</source>
        <translation>Aktív modulok:</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Hálózat</translation>
    </message>
    <message>
        <source>Direct connection</source>
        <translation>Közvetlen kapcsolat</translation>
    </message>
    <message>
        <source>Proxy connection</source>
        <translation>Proxyn keresztül</translation>
    </message>
    <message>
        <source>Use system proxy</source>
        <translation>Rendszer proxy használata</translation>
    </message>
    <message>
        <source>Use custom proxy</source>
        <translation>Egyéni proxy használata</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Kiszolgáló:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Hitelesítés</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Felhasználónév:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Jelszó:</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Bal</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Jobb</translation>
    </message>
    <message>
        <source>kBytes</source>
        <translation>kilobájt</translation>
    </message>
    <message>
        <source>MBytes</source>
        <translation>Megabájt</translation>
    </message>
    <message>
        <source>GBytes</source>
        <translation>Gigabájt</translation>
    </message>
    <message numerus="yes">
        <source>day(s)</source>
        <translation>
            <numerusform>nap(ok)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>month(s)</source>
        <translation>
            <numerusform>hónap(ok)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>second(s)</source>
        <translation>
            <numerusform>másodperc(ek)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>minute(s)</source>
        <translation>
            <numerusform>perc(ek)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>hour(s)</source>
        <translation>
            <numerusform>óra</numerusform>
        </translation>
    </message>
    <message>
        <source>Set position</source>
        <translation>Pozíció beállítása</translation>
    </message>
    <message>
        <source>Changes won&apos;t be applied. Are you sure?</source>
        <translation>Változások nincsenek ekfogadva. Biztos benne?</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Történet törlése</translation>
    </message>
    <message>
        <source>Are you sure?</source>
        <translation>Biztos benne?</translation>
    </message>
</context>
<context>
    <name>SmugMug::DialogWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <source>Edit SmugMug item</source>
        <translation>SmugMug szerkesztése</translation>
    </message>
    <message>
        <source>Add SmugMug item</source>
        <translation>SmugMug hozzáadása</translation>
    </message>
</context>
<context>
    <name>SmugMug::Item</name>
    <message>
        <source>Text:</source>
        <translation>Szöveg:</translation>
    </message>
</context>
<context>
    <name>SplashScreen</name>
    <message>
        <source>Loading Files module ...</source>
        <translation>Fájl modul betöltése ...</translation>
    </message>
    <message>
        <source>Loading Folders module ...</source>
        <translation>Mappa modul betöltése ...</translation>
    </message>
    <message>
        <source>Loading Flickr module ...</source>
        <translation>Flickr modul betöltése ...</translation>
    </message>
    <message>
        <source>Loading Yahoo! module ...</source>
        <translation>Yahoo! modul betöltése ...</translation>
    </message>
    <message>
        <source>Loading Panoramio module ...</source>
        <translation>Panoramio modul betöltése ...</translation>
    </message>
    <message>
        <source>Loading Ipernity module ...</source>
        <translation>Ipernity modul betöltése ...</translation>
    </message>
    <message>
        <source>Loading Photobucket module ...</source>
        <translation>Photobucket modul betöltése ...</translation>
    </message>
    <message>
        <source>Loading Buzznet module ...</source>
        <translation>Buzznet modul betöltése ...</translation>
    </message>
    <message>
        <source>Loading Picasa module ...</source>
        <translation>Picasa modul betöltése ...</translation>
    </message>
    <message>
        <source>Loading SmugMug module ...</source>
        <translation>SmugMug modul betöltése ...</translation>
    </message>
    <message>
        <source>Loading Google module ...</source>
        <translation>Google modul betöltése ...</translation>
    </message>
    <message>
        <source>Loading Vladstudio module ...</source>
        <translation>Vladstudio modul betöltése ...</translation>
    </message>
    <message>
        <source>Loading deviantART module ...</source>
        <translation>devianART modul betöltése ...</translation>
    </message>
    <message>
        <source>Loading settings ...</source>
        <translation>Beállítások betöltése ...</translation>
    </message>
    <message>
        <source>Launching Wally ...</source>
        <translation>Wally indítása ...</translation>
    </message>
    <message>
        <source>Author:</source>
        <translation>Készítette:</translation>
    </message>
</context>
<context>
    <name>Viewer</name>
    <message>
        <source>Right-click on photo to show actions</source>
        <translation>Jobb klikk a fotón megmutatja a lehetőségeket</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ablakhoz igazítás</translation>
    </message>
    <message>
        <source>Show full image</source>
        <translation>Teljes kép mutatása</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Nagyítás</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Kicsinyítés</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Jobbra forgatás</translation>
    </message>
    <message>
        <source>Rotate c. clockwise</source>
        <translation>Balra forgatás</translation>
    </message>
</context>
<context>
    <name>Vladstudio::DialogWidget</name>
    <message>
        <source>All</source>
        <translation>Mind</translation>
    </message>
    <message>
        <source>Abstract art</source>
        <translation>Absztrakt</translation>
    </message>
    <message>
        <source>Creatures</source>
        <translation>Élőlények</translation>
    </message>
    <message>
        <source>Illustrations</source>
        <translation>Illusztrációk</translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Fotók</translation>
    </message>
    <message>
        <source>By ID</source>
        <translation>ID szerint</translation>
    </message>
    <message>
        <source>By view count</source>
        <translation>Látogatottság szerint</translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation>Növekvő</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation>Csökkenő</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategóriák:</translation>
    </message>
    <message>
        <source>Order:</source>
        <translation>Sorrend:</translation>
    </message>
    <message>
        <source>Direction:</source>
        <translation>Hely:</translation>
    </message>
    <message>
        <source>Edit Vladstudio item</source>
        <translation>Vladstudio szerkesztése</translation>
    </message>
    <message>
        <source>Add Vladstudio item</source>
        <translation>Vladstudio hozzáadása</translation>
    </message>
</context>
<context>
    <name>Vladstudio::Item</name>
    <message>
        <source>All categories</source>
        <translation>Mineden kategória</translation>
    </message>
    <message>
        <source>Abstract art</source>
        <translation>Absztrakt</translation>
    </message>
    <message>
        <source>Creatures</source>
        <translation>Élőlények</translation>
    </message>
    <message>
        <source>Illustrations</source>
        <translation>Illusztrációk</translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Képek</translation>
    </message>
    <message>
        <source>by Id</source>
        <translation>ID szerint</translation>
    </message>
    <message>
        <source>by view count</source>
        <translation>Látogatottság szerint</translation>
    </message>
    <message>
        <source>ascending</source>
        <translation>növekvő</translation>
    </message>
    <message>
        <source>descending</source>
        <translation>csökkenő</translation>
    </message>
</context>
<context>
    <name>Wally::Application</name>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Indít</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szünet</translation>
    </message>
    <message>
        <source>Next photo</source>
        <translation>Következő</translation>
    </message>
    <message>
        <source>Save photo...</source>
        <translation>Fotó mentése...</translation>
    </message>
    <message>
        <source>Get EXIF info...</source>
        <translation>EXIF adatok megtekintése...</translation>
    </message>
    <message>
        <source>Settings...</source>
        <translation>Beállítások...</translation>
    </message>
    <message>
        <source>Explore source</source>
        <translation>Forrás kutatása</translation>
    </message>
    <message>
        <source>About...</source>
        <translation>Névjegy...</translation>
    </message>
    <message>
        <source>History...</source>
        <translation>Történet...</translation>
    </message>
    <message>
        <source>About Qt...</source>
        <translation>Qt névjegye...</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Kilép</translation>
    </message>
    <message>
        <source>Languages</source>
        <translation>Nyelvek</translation>
    </message>
    <message>
        <source>English</source>
        <translation>angol</translation>
    </message>
    <message>
        <source>Italian</source>
        <translation>olasz</translation>
    </message>
    <message>
        <source>Spanish</source>
        <translation>spanyol</translation>
    </message>
    <message>
        <source>German</source>
        <translation>német</translation>
    </message>
    <message>
        <source>French</source>
        <translation>francia</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>orosz</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation>portugál (brazil)</translation>
    </message>
    <message>
        <source>Czech</source>
        <translation>cseh</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation>lengyel</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>kínai</translation>
    </message>
    <message>
        <source>Catalan</source>
        <translation>katalán</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation>görög</translation>
    </message>
    <message>
        <source>Korean</source>
        <translation>koreai</translation>
    </message>
    <message>
        <source>Wally Error</source>
        <translation>Wally hiba</translation>
    </message>
    <message>
        <source>Active Desktop must be disabled</source>
        <translation>Aktív asztal nem érhető el</translation>
    </message>
    <message>
        <source>by:</source>
        <translation>készítő:</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Hely:</translation>
    </message>
    <message>
        <source>Engine:</source>
        <translation>Forrás:</translation>
    </message>
    <message>
        <source>Save photo</source>
        <translation>Fotó mentése</translation>
    </message>
    <message>
        <source>Images (*.png *.xpm *.jpg)</source>
        <translation>Képek (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <source>Right-click to show main menu</source>
        <translation>Jobb klikk megmutaja a főmenüt</translation>
    </message>
    <message>
        <source>Hungarian</source>
        <translation>Magyar</translation>
    </message>
    <message>
        <source>Danish</source>
        <translation>Dán</translation>
    </message>
    <message>
        <source>Swedish</source>
        <translation>Svéd</translation>
    </message>
    <message>
        <source>Turkish</source>
        <translation>Török</translation>
    </message>
</context>
<context>
    <name>Yahoo::DialogWidget</name>
    <message>
        <source>All of these words</source>
        <translation>Minden szó</translation>
    </message>
    <message>
        <source>Any of these words</source>
        <translation>Bármely szó</translation>
    </message>
    <message>
        <source>Search for:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <source>Filter content</source>
        <translation>Szűrő tartalom</translation>
    </message>
    <message>
        <source>Yahoo! item</source>
        <translation>Yahoo! cikkely</translation>
    </message>
    <message>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>A nem szűrt tartalomban megjelennek a sértő és szexuális fotók</translation>
    </message>
    <message>
        <source>Edit Yahoo! item</source>
        <translation>Yahoo! szerkesztése</translation>
    </message>
    <message>
        <source>Add Yahoo! item</source>
        <translation>Yahoo! hozzáadása</translation>
    </message>
</context>
<context>
    <name>Yahoo::Item</name>
    <message>
        <source>Tags:</source>
        <translation>Címkék:</translation>
    </message>
    <message>
        <source>and</source>
        <translation>és</translation>
    </message>
    <message>
        <source>or</source>
        <translation>vagy</translation>
    </message>
    <message>
        <source>content filtered</source>
        <translation>tartalom szűrve</translation>
    </message>
</context>
</TS>
